=======
History
=======

0.1.3 (2017-09-10)
------------------

* Actually fix when only benchmarking one function (no K-S test) (oops).

0.1.2 (2017-09-10)
------------------

* Fix when only benchmarking one function (no K-S test).

0.1.1 (2017-08-27)
------------------

* Add dependency on matplotlib.

0.1.0 (2017-08-27)
------------------

* First release on PyPI.
* Interactive histogram while benchmarking with bokeh.
* Interactive descriptive stats and K-S test.
* Cumulative distribution plots.
* Bucketed resampling.
